@@ -55,8 +55,11 @@ from asposeslidescloud.models.files_upload_result import FilesUploadResult
 from asposeslidescloud.models.fill_format import FillFormat
 from asposeslidescloud.models.fill_overlay_effect import FillOverlayEffect
 from asposeslidescloud.models.font_set import FontSet
+from asposeslidescloud.models.geometry_path import GeometryPath
+from asposeslidescloud.models.geometry_paths import GeometryPaths
 from asposeslidescloud.models.glow_effect import GlowEffect
 from asposeslidescloud.models.gradient_fill_stop import GradientFillStop
+from asposeslidescloud.models.hyperlink import Hyperlink
 from asposeslidescloud.models.i_shape_export_options import IShapeExportOptions
 from asposeslidescloud.models.image_export_format import ImageExportFormat
 from asposeslidescloud.models.inner_shadow_effect import InnerShadowEffect
@@ -66,6 +69,8 @@ from asposeslidescloud.models.interactive_sequence import InteractiveSequence
 from asposeslidescloud.models.legend import Legend
 from asposeslidescloud.models.light_rig import LightRig
 from asposeslidescloud.models.line_format import LineFormat
+from asposeslidescloud.models.math_element import MathElement
+from asposeslidescloud.models.math_paragraph import MathParagraph
 from asposeslidescloud.models.merging_source import MergingSource
 from asposeslidescloud.models.normal_view_restored_properties import NormalViewRestoredProperties
 from asposeslidescloud.models.notes_slide_export_format import NotesSlideExportFormat
@@ -73,6 +78,7 @@ from asposeslidescloud.models.object_exist import ObjectExist
 from asposeslidescloud.models.ordered_merge_request import OrderedMergeRequest
 from asposeslidescloud.models.outer_shadow_effect import OuterShadowEffect
 from asposeslidescloud.models.output_file import OutputFile
+from asposeslidescloud.models.path_segment import PathSegment
 from asposeslidescloud.models.pipeline import Pipeline
 from asposeslidescloud.models.plot_area import PlotArea
 from asposeslidescloud.models.presentation_to_merge import PresentationToMerge
@@ -101,30 +107,51 @@ from asposeslidescloud.models.table_row import TableRow
 from asposeslidescloud.models.task import Task
 from asposeslidescloud.models.text_item import TextItem
 from asposeslidescloud.models.three_d_format import ThreeDFormat
+from asposeslidescloud.models.accent_element import AccentElement
 from asposeslidescloud.models.add_layout_slide import AddLayoutSlide
 from asposeslidescloud.models.add_master_slide import AddMasterSlide
 from asposeslidescloud.models.add_shape import AddShape
 from asposeslidescloud.models.add_slide import AddSlide
+from asposeslidescloud.models.arc_to_path_segment import ArcToPathSegment
+from asposeslidescloud.models.array_element import ArrayElement
+from asposeslidescloud.models.bar_element import BarElement
 from asposeslidescloud.models.base64_input_file import Base64InputFile
+from asposeslidescloud.models.block_element import BlockElement
+from asposeslidescloud.models.border_box_element import BorderBoxElement
+from asposeslidescloud.models.box_element import BoxElement
 from asposeslidescloud.models.bubble_series import BubbleSeries
+from asposeslidescloud.models.close_path_segment import ClosePathSegment
 from asposeslidescloud.models.color_scheme import ColorScheme
+from asposeslidescloud.models.cubic_bezier_to_path_segment import CubicBezierToPathSegment
+from asposeslidescloud.models.delimiter_element import DelimiterElement
 from asposeslidescloud.models.document import Document
 from asposeslidescloud.models.document_properties import DocumentProperties
 from asposeslidescloud.models.document_property import DocumentProperty
 from asposeslidescloud.models.file_version import FileVersion
 from asposeslidescloud.models.font_scheme import FontScheme
 from asposeslidescloud.models.format_scheme import FormatScheme
+from asposeslidescloud.models.fraction_element import FractionElement
+from asposeslidescloud.models.function_element import FunctionElement
+from asposeslidescloud.models.gif_export_options import GifExportOptions
 from asposeslidescloud.models.gradient_fill import GradientFill
+from asposeslidescloud.models.grouping_character_element import GroupingCharacterElement
 from asposeslidescloud.models.header_footer import HeaderFooter
+from asposeslidescloud.models.html5_export_options import Html5ExportOptions
 from asposeslidescloud.models.html_export_options import HtmlExportOptions
 from asposeslidescloud.models.image import Image
 from asposeslidescloud.models.image_export_options import ImageExportOptions
 from asposeslidescloud.models.images import Images
 from asposeslidescloud.models.layout_slide import LayoutSlide
 from asposeslidescloud.models.layout_slides import LayoutSlides
+from asposeslidescloud.models.left_sub_superscript_element import LeftSubSuperscriptElement
+from asposeslidescloud.models.limit_element import LimitElement
+from asposeslidescloud.models.line_to_path_segment import LineToPathSegment
 from asposeslidescloud.models.master_slide import MasterSlide
 from asposeslidescloud.models.master_slides import MasterSlides
+from asposeslidescloud.models.matrix_element import MatrixElement
 from asposeslidescloud.models.merge import Merge
+from asposeslidescloud.models.move_to_path_segment import MoveToPathSegment
+from asposeslidescloud.models.nary_operator_element import NaryOperatorElement
 from asposeslidescloud.models.no_fill import NoFill
 from asposeslidescloud.models.notes_slide import NotesSlide
 from asposeslidescloud.models.notes_slide_header_footer import NotesSlideHeaderFooter
@@ -143,6 +170,8 @@ from asposeslidescloud.models.portion import Portion
 from asposeslidescloud.models.portions import Portions
 from asposeslidescloud.models.pptx_export_options import PptxExportOptions
 from asposeslidescloud.models.protection_properties import ProtectionProperties
+from asposeslidescloud.models.quadratic_bezier_to_path_segment import QuadraticBezierToPathSegment
+from asposeslidescloud.models.radical_element import RadicalElement
 from asposeslidescloud.models.remove_shape import RemoveShape
 from asposeslidescloud.models.remove_slide import RemoveSlide
 from asposeslidescloud.models.reorder_slide import ReorderSlide
@@ -150,6 +179,7 @@ from asposeslidescloud.models.replace_text import ReplaceText
 from asposeslidescloud.models.request_input_file import RequestInputFile
 from asposeslidescloud.models.reset_slide import ResetSlide
 from asposeslidescloud.models.response_output_file import ResponseOutputFile
+from asposeslidescloud.models.right_sub_superscript_element import RightSubSuperscriptElement
 from asposeslidescloud.models.save import Save
 from asposeslidescloud.models.save_shape import SaveShape
 from asposeslidescloud.models.save_slide import SaveSlide
@@ -167,14 +197,18 @@ from asposeslidescloud.models.slide_properties import SlideProperties
 from asposeslidescloud.models.slides import Slides
 from asposeslidescloud.models.solid_fill import SolidFill
 from asposeslidescloud.models.split_document_result import SplitDocumentResult
+from asposeslidescloud.models.subscript_element import SubscriptElement
+from asposeslidescloud.models.superscript_element import SuperscriptElement
 from asposeslidescloud.models.svg_export_options import SvgExportOptions
 from asposeslidescloud.models.swf_export_options import SwfExportOptions
+from asposeslidescloud.models.text_element import TextElement
 from asposeslidescloud.models.text_items import TextItems
 from asposeslidescloud.models.theme import Theme
 from asposeslidescloud.models.tiff_export_options import TiffExportOptions
 from asposeslidescloud.models.update_background import UpdateBackground
 from asposeslidescloud.models.update_shape import UpdateShape
 from asposeslidescloud.models.view_properties import ViewProperties
+from asposeslidescloud.models.xaml_export_options import XamlExportOptions
 from asposeslidescloud.models.xps_export_options import XpsExportOptions
 from asposeslidescloud.models.box_and_whisker_series import BoxAndWhiskerSeries
 from asposeslidescloud.models.bubble_chart_data_point import BubbleChartDataPoint
