@@ -44,10 +44,10 @@ class TiffExportOptions(ExportOptions):
     """
     swagger_types = {
         'default_regular_font': 'str',
+        'height': 'int',
+        'width': 'int',
         'format': 'str',
         'compression': 'str',
-        'width': 'int',
-        'height': 'int',
         'dpi_x': 'int',
         'dpi_y': 'int',
         'show_hidden_slides': 'bool',
@@ -61,10 +61,10 @@ class TiffExportOptions(ExportOptions):
 
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
+        'height': 'height',
+        'width': 'width',
         'format': 'format',
         'compression': 'compression',
-        'width': 'width',
-        'height': 'height',
         'dpi_x': 'dpiX',
         'dpi_y': 'dpiY',
         'show_hidden_slides': 'showHiddenSlides',
@@ -80,13 +80,11 @@ class TiffExportOptions(ExportOptions):
         'format': 'tiff',
     }
 
-    def __init__(self, default_regular_font=None, format='tiff', compression=None, width=None, height=None, dpi_x=None, dpi_y=None, show_hidden_slides=None, pixel_format=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, height=None, width=None, format='tiff', compression=None, dpi_x=None, dpi_y=None, show_hidden_slides=None, pixel_format=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
         """TiffExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(TiffExportOptions, self).__init__(default_regular_font, format)
+        super(TiffExportOptions, self).__init__(default_regular_font, height, width, format)
 
         self._compression = None
-        self._width = None
-        self._height = None
         self._dpi_x = None
         self._dpi_y = None
         self._show_hidden_slides = None
@@ -98,23 +96,26 @@ class TiffExportOptions(ExportOptions):
         self._show_comments_by_no_author = None
         self.format = 'tiff'
 
-        self.compression = compression
-        if width is not None:
-            self.width = width
-        if height is not None:
-            self.height = height
+        if compression is not None:
+            self.compression = compression
         if dpi_x is not None:
             self.dpi_x = dpi_x
         if dpi_y is not None:
             self.dpi_y = dpi_y
-        self.show_hidden_slides = show_hidden_slides
-        self.pixel_format = pixel_format
-        self.notes_position = notes_position
-        self.comments_position = comments_position
-        self.comments_area_width = comments_area_width
+        if show_hidden_slides is not None:
+            self.show_hidden_slides = show_hidden_slides
+        if pixel_format is not None:
+            self.pixel_format = pixel_format
+        if notes_position is not None:
+            self.notes_position = notes_position
+        if comments_position is not None:
+            self.comments_position = comments_position
+        if comments_area_width is not None:
+            self.comments_area_width = comments_area_width
         if comments_area_color is not None:
             self.comments_area_color = comments_area_color
-        self.show_comments_by_no_author = show_comments_by_no_author
+        if show_comments_by_no_author is not None:
+            self.show_comments_by_no_author = show_comments_by_no_author
 
     @property
     def compression(self):
@@ -154,50 +155,6 @@ class TiffExportOptions(ExportOptions):
                 )
         self._compression = compression
 
-    @property
-    def width(self):
-        """Gets the width of this TiffExportOptions.  # noqa: E501
-
-        Width.  # noqa: E501
-
-        :return: The width of this TiffExportOptions.  # noqa: E501
-        :rtype: int
-        """
-        return self._width
-
-    @width.setter
-    def width(self, width):
-        """Sets the width of this TiffExportOptions.
-
-        Width.  # noqa: E501
-
-        :param width: The width of this TiffExportOptions.  # noqa: E501
-        :type: int
-        """
-        self._width = width
-
-    @property
-    def height(self):
-        """Gets the height of this TiffExportOptions.  # noqa: E501
-
-        Height.  # noqa: E501
-
-        :return: The height of this TiffExportOptions.  # noqa: E501
-        :rtype: int
-        """
-        return self._height
-
-    @height.setter
-    def height(self, height):
-        """Sets the height of this TiffExportOptions.
-
-        Height.  # noqa: E501
-
-        :param height: The height of this TiffExportOptions.  # noqa: E501
-        :type: int
-        """
-        self._height = height
-
     @property
     def dpi_x(self):
         """Gets the dpi_x of this TiffExportOptions.  # noqa: E501
